@@ -1,4 +1,4 @@
-/* $Id: glibtop.h,v 1.39 2005/06/07 09:54:43 bdejean Exp $ */
+/* $Id: glibtop.h,v 1.41 2006/08/10 20:36:57 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,6 +24,10 @@
 #ifndef __GLIBTOP_H__
 #define __GLIBTOP_H__
 
+#include <glib/gmacros.h>
+
+G_BEGIN_DECLS
+
 typedef struct _glibtop		glibtop;
 
 /**
@@ -77,6 +81,7 @@ struct _glibtop
 	int output [2];			/* Pipe client -> server */
 	int socket;			/* Accepted connection of a socket */
 	int ncpu;			/* Number of CPUs, zero if single-processor */
+	int real_ncpu;			/* Real number of CPUs. Only ncpu are monitored */
 	unsigned long os_version_code;	/* Version code of the operating system */
 	const char *name;		/* Program name for error messages */
 	const char *server_command;	/* Command used to invoke server */
@@ -107,4 +112,6 @@ glibtop_init_s (glibtop **server_ptr,
 		unsigned long features,
 		unsigned flags);
 
+G_END_DECLS
+
 #endif
