@@ -3,9 +3,13 @@
 
 #include <glibtop.h>
 
+G_BEGIN_DECLS
+
 typedef void (*glibtop_init_func_t)(glibtop *);
 
 extern const glibtop_init_func_t _glibtop_init_hook_s[];
 extern const glibtop_init_func_t _glibtop_init_hook_p[];
 
+G_END_DECLS
+
 #endif /* H_LIBGTOP_INIT_HOOKS_1122955666 */
