@@ -1,4 +1,4 @@
-/* $Id: procstate.h,v 1.30 2006/04/18 20:17:25 gpoo Exp $ */
+/* $Id: procstate.h,v 1.31 2006/09/10 21:53:29 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -58,8 +58,7 @@ struct _glibtop_proc_state
 	guint64 flags;
 	char cmd[40];		/* basename of executable file in
 				 * call to exec(2) */
-	unsigned state;		/* single-char code for process state
-				 * (S=sleeping) */
+	unsigned state;
 	/* NOTE: when porting the library, TRY HARD to implement the
 	 *       following two fields. */
 	/* IMPORTANT NOTICE: For security reasons, it is extremely important
