@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.8 2004/10/04 11:57:05 bdejean Exp $ */
+/* $Id: procargs.c,v 1.10 2005/12/12 09:38:10 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <procinfo.h>
 
 #include <glibtop.h>
@@ -67,12 +68,7 @@ glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
 	memset (buf, 0, sizeof (glibtop_proc_args));
 
 	pinfo = _glibtop_get_procinfo(server, pid);
-	if (pinfo == NULL)
-	{
-		glibtop_error_io_r (server, "Cannot read procsinfo");
-
-		return NULL;
-	}
+	if (pinfo == NULL) return NULL;
 
 	size = max_len != 0 ? max_len : 4096;
 	args_buffer = g_malloc (size);
