@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.20 2004/03/09 23:02:02 hadess Exp $ */
+/* $Id: procargs.c,v 1.23 2005/12/12 09:38:11 jamesh Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procargs.h>
@@ -50,7 +51,7 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 {
 	struct kinfo_proc *pinfo;
 	char *retval, **args, **ptr;
-	unsigned size = 0, pos = 0;
+	size_t size = 0, pos = 0;
 	int count;
 
 #ifndef __bsdi__
@@ -59,7 +60,7 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 #endif
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_args));
 
 	/* swapper, init, pagedaemon, vmdaemon, update - this doen't work. */
@@ -93,11 +94,10 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 		size += strlen (*ptr)+1;
 
 	size += 2;
-	retval = g_malloc (size);
-	memset (retval, 0, size);
+	retval = g_malloc0 (size);
 
 	for (ptr = args; *ptr; ptr++) {
-		int len = strlen (*ptr)+1;
+		const size_t len = strlen (*ptr)+1;
 		memcpy (retval+pos, *ptr, len);
 		pos += len;
 	}
